export class Logger {
    constructor(id, level) {
        this._id = id;
        this._level = Logger._toValue(level);
    }
    setLevel(level) {
        this._level = Logger._toValue(level);
    }
    setId(id) {
        this._id = id;
    }
    debug(text) {
        if (this._level >= Logger._DEBUG) {
            // eslint-disable-next-line no-console
            console.log(this._consoleText(text));
        }
    }
    warn(text) {
        if (this._level >= Logger._WARN) {
            // eslint-disable-next-line no-console
            console.warn(this._consoleText(text));
        }
    }
    error(text) {
        if (this._level >= Logger._ERROR) {
            // eslint-disable-next-line no-console
            console.error(this._consoleText(text));
        }
    }
    static _toValue(level) {
        const loglevel = (level || '').toLowerCase();
        if (loglevel === 'debug') {
            return Logger._DEBUG;
        }
        if (loglevel === 'trace') {
            return Logger._DEBUG;
        }
        if (loglevel === 'notice') {
            return Logger._DEBUG;
        }
        if (loglevel === 'info') {
            return Logger._INFO;
        }
        if (loglevel.startsWith('warn')) {
            return Logger._WARN;
        }
        if (loglevel.startsWith('err')) {
            return Logger._ERROR;
        }
        if (loglevel === 'fatal') {
            return Logger._FATAL;
        }
        return Logger._OFF;
    }
    _consoleText(text) {
        return this._id ? `[${this._id}] ${text}` : text;
    }
}
Logger._OFF = 0;
Logger._FATAL = 1;
Logger._ERROR = 2;
Logger._WARN = 3;
Logger._INFO = 4;
Logger._DEBUG = 5;
//# sourceMappingURL=Logger.js.map